NLSL: ddot.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
ddot.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
double precision function | ddot (n, dx, incx, dy, incy)

## Function/Subroutine Documentation

double precision function ddot | ( | integer | n,
|  | double precision, dimension(1) | dx,
|  | integer | incx,
|  | double precision, dimension(1) | dy,
|  | integer | incy
| ) |  |

Definition at line 2 of file ddot.f90.